@@ -133,10 +133,10 @@ import sys
 import gc
 import logging
 import compiler
-from sets import Set
 from types import UnboundMethodType, FunctionType, ClassType
 import linecache
 
+
 #############################################################################
 # Public functions
 #############################################################################
@@ -266,8 +266,8 @@ class Refresher(object):
                     #        to identify dynamically attached methods that 
                     #        might need to remain attached.  
 
-                    new_attrs = Set(new_class.__dict__.keys())
-                    old_attrs = Set(old_class.__dict__.keys())
+                    new_attrs = set(new_class.__dict__.keys())
+                    old_attrs = set(old_class.__dict__.keys())
                     
                     # attributes in old_class that aren't in new class.
                     # and get rid of them.
